@@ -6,7 +6,10 @@
 #'   trees_filename <- get_tracerer_path("beast2_example_output.trees")
 #'   posterior <- parse_beast_trees(trees_filename)
 #'   testit::assert(is_trees_posterior(posterior))
-#' @author Richel J.C. Bilderbeek
+#' @seealso
+#'   Use \code{\link{save_beast_trees}} to save the phylogenies
+#'   to a \code{.trees} file.
+#' @author Richèl J.C. Bilderbeek
 parse_beast_trees <- function(
   filename
 ) {
@@ -19,6 +22,7 @@ parse_beast_trees <- function(
   }
 
   trees <- tryCatch({
+      # Cannot use ape::read.tree, as that's incompatible with BEAST2's output
       ape::read.nexus(filename)
     },
     error = function(cond) {
@@ -31,5 +35,12 @@ parse_beast_trees <- function(
 
   class(trees) <- "multiPhylo"
   # Use c to strip the state names and convert it to a pure multiPhylo
-  c(trees)
+  trees <- c(trees)
+
+  # Check if it matches the file
+  n_trees_in_file <- tracerer::count_trees_in_file(filename)
+  n_trees_in_output <- length(trees)
+  testit::assert(n_trees_in_file == n_trees_in_output)
+
+  trees
 }
